@@ -1,41 +1,4 @@
-#function that checks if URL works and fails gracefully if not
-gracefully_fail <- function(remote_file) {
-  try_GET <- function(x, ...) {
-    tryCatch(
-      httr::GET(url = x, httr::timeout(10), ...),
-      error = function(e) conditionMessage(e),
-      warning = function(w) conditionMessage(w)
-    )
-  }
-  is_response <- function(x) {
-    class(x) == "response"
-  }
-
-  # First check internet connection
-  if (!curl::has_internet()) {
-    message("No internet connection.")
-    return(invisible(NULL))
-  }
-  # Then try for timeout problems
-  resp <- try_GET(remote_file)
-  if (!is_response(resp)) {
-    message(resp)
-    return(invisible(NULL))
-  }
-  # Then stop if status > 400
-  if (httr::http_error(resp)) {
-    httr::message_for_status(resp)
-    return(invisible(NULL))
-  }
-
-  # If you are using rvest as I do you can easily read_html in the response
-  rvest::read_html(remote_file)
-
-  # If none of the tests fail, return "OK" response
-  return("OK")
-}
-
-agency <- month <- TOS <- Modes <- ntd_id_5 <- NULL
+agency <- month <- ntd_id_5 <- NULL
 
 #' Get NTD data
 #'
@@ -193,6 +156,3 @@ get_ntd_url <- function(data_type = "adjusted") {
 #   stopifnot("The archived data cannot be reached. Check your internet connection, try again later, or set `cache = FALSE`." = check_board_status())
 #   ntdr_board <- pins::board_url("https://ntdr-pins.s3.us-west-2.amazonaws.com/")
 # }
-
-
-
